@@ -1,36 +1,17 @@
 /* -*- C++ -*-
+    This file implements the DestructedState class.
 
-This file implements the DestructedState class.
+    SPDX-FileCopyrightText: 2005-2013 Mirko Boehm <mirko@kde.org>
 
-$ Author: Mirko Boehm $
-$ Copyright: (C) 2005-2013 Mirko Boehm $
-$ Contact: mirko@kde.org
-https://www.kde.org
-http://creative-destruction.me $
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-
-$Id: DestructedState.cpp 30 2005-08-16 16:16:04Z mirko $
+    $Id: DestructedState.cpp 30 2005-08-16 16:16:04Z mirko $
 */
 
 #include "destructedstate.h"
 
 namespace ThreadWeaver
 {
-
 DestructedState::DestructedState(QueueSignals *)
     : WeaverImplState(nullptr) // make sure we cannot use weaver, ever :-)
 {
@@ -64,7 +45,7 @@ int DestructedState::currentNumberOfThreads() const
     return 0;
 }
 
-void DestructedState::enqueue(const QVector<JobPointer> &)
+void DestructedState::enqueue(const QList<JobPointer> &)
 {
 }
 
